==> SCET-1.5.3.tar.gz: SCET-1.5.3/src/scet/main.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import os
carpeta_madre = os.path.abspath(os.path.dirname(__file__))
import logging
logging.basicConfig(filename=os.path.join(carpeta_madre,'registro.log'), filemode='w', level=logging.DEBUG)
import time
import datetime
import sys
import traceback
import time
import subprocess
import pip

from tkinter import Tk, Toplevel, messagebox, ttk
from mysql import connector

from scet.libsa import Ventana, Base_Entrada, Formulario, Bucle, Tabla, Reporte, seguro, ControladorEstado
from scet.bd_xml import Tabla
from scet import Ventanas


__NOMBRE__ = 'SCET'
__VERSION__ = "1.5.3"
__AUTOR__ = 'Wolfang A. Torres G.'
__TITULO__ = 'Capibara Re-Instalado'
__FECHA__ = datetime.date(2015, 7, 13)
__CONTACTO__ = 'Wolfang.Torres@gmail.com'

__registro__ = logging.getLogger(__NOMBRE__)

carpeta_guis = os.path.join(carpeta_madre, 'InterfacesGraficas')
carpeta_bd = os.path.join(carpeta_madre, 'BaseDeDatos')
carpeta_error = os.path.join(carpeta_madre, 'Errores')

carpeta_recursos = os.path.join(carpeta_madre, 'recursos')
iconos = os.path.join(carpeta_recursos, 'iconos_gris')
simbolos = os.path.join(carpeta_recursos, 'simbolos_orig')

_estilos = {
    'linux':'clam',
    'win32':'clam',
    }

_fuente = ('Helvetica', 11)
_fuente_titulo = _fuente + ('bold',)

Ventana.carpeta_guis = carpeta_guis
for carpeta in (carpeta_recursos, iconos, simbolos):
    Ventana.carpetas_recursos.append(carpeta)


class inicio_seccion(Ventana, Base_Entrada):
    archivo_gui = "Inicio_seccion"
    dir = os.path.join(carpeta_bd, 'BD_login.xml')
    ok = False

    def __init__(self, master):
        self.master = master
        self.master.wm_title(__NOMBRE__)
        Ventana.__init__(self, self.master, self.archivo_gui, True)
        self.__gui__.get_object('contraseña').focus()

        self.__tabla__ = Tabla()
        __registro__.debug('Pantalla de incio de sesion creada')

        try:
            __registro__.debug('Buscar archivo informacion comun')
            with open(self.dir, 'r') as preferencias:
                self.__tabla__.xml = preferencias.read()

        except IOError as err:
            __registro__.debug('Archivo no encontrada, creando uno generico')
            self._crear_archivo_preferencias()

            with open(self.dir, 'w') as preferencias:
                preferencias.write(self.__tabla__.xml)

        self._sincronisar('formulario', 0, self.__tabla__, 'none_a_str')
        __registro__.debug('Preferencias escritas en el formulario')

    @seguro
    def aceptar_ser(self, event=None):
        self.__tabla__[0] = self.datos
        try:
            self.config = self.__tabla__[0]
            c = connector.connect(**self.config)

        except connector.errors.ProgrammingError as err:
            messagebox.showinfo(message='Error de Coneccion',
                                icon="error", title="Error",
                                detail="""Los datos suministrados no son validos""")
            __registro__.warning('''Intento de coneccion no exitoso, {}
{}'''.format(err, self.config))
        else:
            self.ok = True
            self.master.destroy()
            __registro__.debug('Itento de coneccion exitoso')

    @seguro
    def salir(self):
        self.master.destroy()

    @seguro
    def guardar(self):
        self._crear_archivo_preferencias()
        self.__tabla__[0] = self.datos

        with open(self.dir, 'w') as preferencias:
            preferencias.write(self.__tabla__.xml)

        messagebox.showinfo(
            message='Guardado exitosamente',
            icon="info",
            title="guardado exitoso"
            )

    def _crear_archivo_preferencias(self):
        self.__tabla__ = Tabla('Preferencias')
        self.__tabla__.agregar_columna(campo='host', tipo='str', defecto='127.0.0.1')
        self.__tabla__.agregar_columna(campo='port', tipo='str', defecto='3306')
        self.__tabla__.agregar_columna(campo='user', tipo='str', defecto='')
        self.__tabla__.agregar_columna(campo='password', tipo='str', defecto='')
        self.__tabla__.agregar_columna(campo='db', tipo='str', defecto='scet')
        #self.__tabla__.agregar_columna(campo='file', tipo='str', defecto='')
        self.__tabla__ += ()


class programa(Ventana):
    __formulario__ = None

    def __init__(self, master):
        self.master = master
        master.wm_title(__NOMBRE__)

        Ventana.__init__(self, master, 'Main', 'menu')

        __estado__ = ControladorEstado(self.__gui__.get_variable('__estado__'))
        self.__estado__ = logging.StreamHandler(stream=__estado__)
        self.__estado__.terminator = ''
        self.__estado__.setLevel(logging.INFO)
        logging.getLogger('').addHandler(self.__estado__)

        self.__marco__ = self.__gui__.get_object('__marco__')

        self._estilo()
        self._login()
        self._menu()

    @seguro
    def _login(self):
        self.master.withdraw()
        ventana = Toplevel(self.master)
        self.login = inicio_seccion(ventana)
        self.master.wait_window(ventana)
        if not self.login.ok:
            __registro__.debug('Pantalla de inicio de secion cerrada, cerrando programa')
            sys.exit(0)
        else:
            self.con = self.login.config
            self.master.deiconify()

    @seguro
    def _estilo(self):
        __registro__.debug('Creando estilo grafico')
        self.estilo = ttk.Style()

        __registro__.debug('Sistema operativo es {}'.format(sys.platform))
        for os, estilo in _estilos.items():
            if os in sys.platform:
                __registro__.debug('Seleccionando estilo {}'.format(estilo))
                s = estilo
                break
        else:
            s = 'default'
            __registro__.debug('No se encontro un estilo para el OS, usando default')

        self.estilo.theme_use(s)

        #conf
        self.estilo.configure('.', font=_fuente, background='white')
        self.estilo.configure('Subtitulo.TLabel', font=_fuente_titulo)
        self.estilo.configure('TNotebook.Tab', font=_fuente_titulo)
        self.estilo.configure('TButton', font=_fuente_titulo)

    def _menu(self):
        menu = self.__gui__.get_object('__menu_usuario__')

        entradaTaller = menu.insert('', 'end', text='Entrada a Taller', tags=('fila', 'a'))
        controlClientes = menu.insert('', 'end', text='Control de Clientes', tags=('fila', 'b'))
        controlRecursos = menu.insert('', 'end', text='Control de Recursos', tags=('fila', 'a'))
        controlEntradas = menu.insert('', 'end', text='Equipos en Taller', tags=('fila', 'b'))
        historialEntradas = menu.insert('', 'end', text='Historial de Trabajos', tags=('fila', 'a'))

        #~ menu.bind('<Double-Button-1>', self._selecionar_menu)
        #~ menu.bind('<Return>', self._selecionar_menu)
        menu.tag_bind('fila', '<Double-Button-1>', self._selecionar_menu)
        menu.tag_bind('fila', '<Return>', self._selecionar_menu)

        menu.tag_configure('fila', font=_fuente_titulo)
        menu.tag_configure('a', background='white')
        menu.tag_configure('b', background='gray')

        self._mapeo_menu_formulario = {
            entradaTaller:Ventanas.Entrada_Taller,
            controlClientes:Ventanas.Control_Clientes,
            controlRecursos:Ventanas.Control_Recursos,
            controlEntradas:Ventanas.Control_Entradas,
            historialEntradas:Ventanas.Historial_Entradas,
        }

    def _selecionar_menu(self, evento):
        menu = evento.widget
        if not menu.selection(): return None

        objeto = menu.selection()[0]

        if objeto in self._mapeo_menu_formulario:
            formulario = self._mapeo_menu_formulario[objeto]
        __registro__.debug('menu: {menu}, objeto: {objeto}, formulario: {formulario}'.format(**locals()))

        if self.__formulario__: self.__formulario__.destruir()

        self.__formulario__ = formulario(self.__marco__, self.con)


    @seguro
    def acerca(self):
        v = Toplevel(self.master)
        v.wm_title("{} - Vercion {}".format(__NOMBRE__, __VERSION__))
        a = acerca(v)

    @seguro
    def actualisar(self):
        __registro__.debug('Ejecutando Actualisador')
        if sys.platform.startswith('linux'):
            #~ r = subprocess.call(['pip', 'install', '--user', '--upgrade', 'scet'])
            r = ['pip', 'install', '--user', '--upgrade', 'scet']
        elif sys.platform.startswith('win'):
            #~ r = subprocess.call(['pip', 'install', '--upgrade', 'scet'])
            r = ['install', '--upgrade', 'scet']
        else:
            r = ['pip', 'install', '--upgrade', 'scet']
        pip.main(r)
        messagebox.showinfo(
            title='Actualisacion Completa',
            message='El programa se cerrara ahora para aplicar los cambios, {}'.format(r),
            )
        sys.exit(0)


class acerca(Ventana):
    def __init__(self, master):
        self.master = master
        master.wm_title(__NOMBRE__)
        Ventana.__init__(self, master, 'acerca')
        self.valores()

    def valores(self):
        self.__gui__.get_variable('vercion').set('{} - Ver. {}'.format(__NOMBRE__,__VERSION__))
        self.__gui__.get_variable('titulo').set(__TITULO__)
        self.__gui__.get_variable('fecha').set(__FECHA__.strftime('%d/%m/%Y'))
        self.__gui__.get_variable('autor').set(__AUTOR__)
        self.__gui__.get_variable('contacto').set(__CONTACTO__)

    def licencia(self):
        archivo = os.path.abspath(os.path.join(os.path.dirname(__file__),'Licencia.html'))
        subprocess.Popen([archivo])

    def manual(self):
        proc = os.path.join(carpeta_madre, 'manual.pdf')
        if sys.platform.startswith('linux'):
            subprocess.Popen(['xdg-open', proc])
        if sys.platform.startswith('win'):
            os.startfile(proc)


def main():
    __registro__.info('{} {}, {}'.format(__NOMBRE__, __VERSION__, __TITULO__))
    try:
        root = Tk()
        root.geometry('{}x{}+0+0'.format(root.winfo_screenwidth(), root.winfo_screenheight()))
        SCET = programa(root)
        root.mainloop()
    except Exception:
        reg = os.path.join(carpeta_madre, 'registro.log')
        error = traceback.format_exc()
        __registro__.critical(error)
        msj = '''Ha ocurrido un error totalmente inesperado y el programa no va a poder continuar,
Por favor envie el archivo
{reg}
 a {autor} en {correo}
        '''.format(reg=reg, autor=__AUTOR__, correo=__CONTACTO__)
        messagebox.showerror(title='Error Critico Encontrado', icon="error", message=msj)


if __name__ == '__main__':
    main()

==> SCET-1.5.4dev2.tar.gz: SCET-1.5.4dev2/src/scet/main.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import os
carpeta_madre = os.path.abspath(os.path.dirname(__file__))
import logging
logging.basicConfig(filename=os.path.join(carpeta_madre,'registro.log'), filemode='w', level=logging.DEBUG)
import time
import datetime
import sys
import traceback
import time
import subprocess
import pip

from tkinter import Tk, Toplevel, messagebox, ttk
from mysql import connector

from scet.libsa import Ventana, Base_Entrada, Formulario, Bucle, Tabla, Reporte, seguro, ControladorEstado
from scet.bd_xml import Tabla
from scet import Ventanas


__NOMBRE__ = 'SCET'
__VERSION__ = "1.5.4dev2"
__AUTOR__ = 'Wolfang A. Torres G.'
__TITULO__ = 'Capibara Re-Instalado'
__FECHA__ = datetime.date(2015, 7, 13)
__CONTACTO__ = 'Wolfang.Torres@gmail.com'

__registro__ = logging.getLogger(__NOMBRE__)

carpeta_guis = os.path.join(carpeta_madre, 'InterfacesGraficas')
carpeta_bd = os.path.join(carpeta_madre, 'BaseDeDatos')
carpeta_error = os.path.join(carpeta_madre, 'Errores')

carpeta_recursos = os.path.join(carpeta_madre, 'recursos')
iconos = os.path.join(carpeta_recursos, 'iconos_gris')
simbolos = os.path.join(carpeta_recursos, 'simbolos_orig')

_estilos = {
    'linux':'clam',
    'win32':'clam',
    }

_fuente = ('Helvetica', 11)
_fuente_titulo = _fuente + ('bold',)

Ventana.carpeta_guis = carpeta_guis
for carpeta in (carpeta_recursos, iconos, simbolos):
    Ventana.carpetas_recursos.append(carpeta)


class inicio_seccion(Ventana, Base_Entrada):
    archivo_gui = "Inicio_seccion"
    dir = os.path.join(carpeta_bd, 'BD_login.xml')
    ok = False

    def __init__(self, master):
        self.master = master
        self.master.wm_title(__NOMBRE__)
        Ventana.__init__(self, self.master, self.archivo_gui, True)
        self.__gui__.get_object('contraseña').focus()

        self.__tabla__ = Tabla()
        __registro__.debug('Pantalla de incio de sesion creada')

        try:
            __registro__.debug('Buscar archivo informacion comun')
            with open(self.dir, 'r') as preferencias:
                self.__tabla__.xml = preferencias.read()

        except IOError as err:
            __registro__.debug('Archivo no encontrada, creando uno generico')
            self._crear_archivo_preferencias()

            with open(self.dir, 'w') as preferencias:
                preferencias.write(self.__tabla__.xml)

        self._sincronisar('formulario', 0, self.__tabla__, 'none_a_str')
        __registro__.debug('Preferencias escritas en el formulario')

    @seguro
    def aceptar_ser(self, event=None):
        self.__tabla__[0] = self.datos
        try:
            self.config = self.__tabla__[0]
            c = connector.connect(**self.config)

        except connector.errors.ProgrammingError as err:
            messagebox.showinfo(message='Error de Coneccion',
                                icon="error", title="Error",
                                detail="""Los datos suministrados no son validos""")
            __registro__.warning('''Intento de coneccion no exitoso, {}
{}'''.format(err, self.config))
        else:
            self.ok = True
            self.master.destroy()
            __registro__.debug('Itento de coneccion exitoso')

    @seguro
    def salir(self):
        self.master.destroy()

    @seguro
    def guardar(self):
        self._crear_archivo_preferencias()
        self.__tabla__[0] = self.datos

        with open(self.dir, 'w') as preferencias:
            preferencias.write(self.__tabla__.xml)

        messagebox.showinfo(
            message='Guardado exitosamente',
            icon="info",
            title="guardado exitoso"
            )

    def _crear_archivo_preferencias(self):
        self.__tabla__ = Tabla('Preferencias')
        self.__tabla__.agregar_columna(campo='host', tipo='str', defecto='127.0.0.1')
        self.__tabla__.agregar_columna(campo='port', tipo='str', defecto='3306')
        self.__tabla__.agregar_columna(campo='user', tipo='str', defecto='')
        self.__tabla__.agregar_columna(campo='password', tipo='str', defecto='')
        self.__tabla__.agregar_columna(campo='db', tipo='str', defecto='scet')
        #self.__tabla__.agregar_columna(campo='file', tipo='str', defecto='')
        self.__tabla__ += ()


class programa(Ventana):
    __formulario__ = None

    def __init__(self, master):
        self.master = master
        master.wm_title(__NOMBRE__)

        Ventana.__init__(self, master, 'Main', 'menu')

        __estado__ = ControladorEstado(self.__gui__.get_variable('__estado__'))
        self.__estado__ = logging.StreamHandler(stream=__estado__)
        self.__estado__.terminator = ''
        self.__estado__.setLevel(logging.INFO)
        logging.getLogger('').addHandler(self.__estado__)

        self.__marco__ = self.__gui__.get_object('__marco__')

        self._estilo()
        self._login()
        self._menu()

    @seguro
    def _login(self):
        self.master.withdraw()
        ventana = Toplevel(self.master)
        self.login = inicio_seccion(ventana)
        self.master.wait_window(ventana)
        if not self.login.ok:
            __registro__.debug('Pantalla de inicio de secion cerrada, cerrando programa')
            sys.exit(0)
        else:
            self.con = self.login.config
            self.master.deiconify()

    @seguro
    def _estilo(self):
        __registro__.debug('Creando estilo grafico')
        self.estilo = ttk.Style()

        __registro__.debug('Sistema operativo es {}'.format(sys.platform))
        for os, estilo in _estilos.items():
            if os in sys.platform:
                __registro__.debug('Seleccionando estilo {}'.format(estilo))
                s = estilo
                break
        else:
            s = 'default'
            __registro__.debug('No se encontro un estilo para el OS, usando default')

        self.estilo.theme_use(s)

        #conf
        self.estilo.configure('.', font=_fuente, background='white')
        self.estilo.configure('Subtitulo.TLabel', font=_fuente_titulo)
        self.estilo.configure('TNotebook.Tab', font=_fuente_titulo)
        self.estilo.configure('TButton', font=_fuente_titulo)

    def _menu(self):
        menu = self.__gui__.get_object('__menu_usuario__')

        entradaTaller = menu.insert('', 'end', text='Entrada a Taller', tags=('fila', 'a'))
        controlClientes = menu.insert('', 'end', text='Control de Clientes', tags=('fila', 'b'))
        controlRecursos = menu.insert('', 'end', text='Control de Recursos', tags=('fila', 'a'))
        controlEntradas = menu.insert('', 'end', text='Equipos en Taller', tags=('fila', 'b'))
        historialEntradas = menu.insert('', 'end', text='Historial de Trabajos', tags=('fila', 'a'))

        #~ menu.bind('<Double-Button-1>', self._selecionar_menu)
        #~ menu.bind('<Return>', self._selecionar_menu)
        menu.tag_bind('fila', '<Double-Button-1>', self._selecionar_menu)
        menu.tag_bind('fila', '<Return>', self._selecionar_menu)

        menu.tag_configure('fila', font=_fuente_titulo)
        menu.tag_configure('a', background='white')
        menu.tag_configure('b', background='gray')

        self._mapeo_menu_formulario = {
            entradaTaller:Ventanas.Entrada_Taller,
            controlClientes:Ventanas.Control_Clientes,
            controlRecursos:Ventanas.Control_Recursos,
            controlEntradas:Ventanas.Control_Entradas,
            historialEntradas:Ventanas.Historial_Entradas,
        }

    def _selecionar_menu(self, evento):
        menu = evento.widget
        if not menu.selection(): return None

        objeto = menu.selection()[0]

        if objeto in self._mapeo_menu_formulario:
            formulario = self._mapeo_menu_formulario[objeto]
        __registro__.debug('menu: {menu}, objeto: {objeto}, formulario: {formulario}'.format(**locals()))

        if self.__formulario__: self.__formulario__.destruir()

        self.__formulario__ = formulario(self.__marco__, self.con)


    @seguro
    def acerca(self):
        v = Toplevel(self.master)
        v.wm_title("{} - Vercion {}".format(__NOMBRE__, __VERSION__))
        a = acerca(v)

    @seguro
    def actualisar(self):
        sys.path.insert(0, 'pkgs')
        __registro__.debug('Ejecutando Actualisador')
        if sys.platform.startswith('linux'):
            r = [ 'install', 'scet', '--user', '--upgrade']
        elif sys.platform.startswith('win'):
            r = ['install', 'scet', '--upgrade']
        else:
            r = ['install', 'scet', '--upgrade']
        pip.main(r)
        messagebox.showinfo(
            title='Actualisacion Completa',
            message='El programa se cerrara ahora para aplicar los cambios, {}'.format(r),
            )
        sys.exit(0)


class acerca(Ventana):
    def __init__(self, master):
        self.master = master
        master.wm_title(__NOMBRE__)
        Ventana.__init__(self, master, 'acerca')
        self.valores()

    def valores(self):
        self.__gui__.get_variable('vercion').set('{} - Ver. {}'.format(__NOMBRE__,__VERSION__))
        self.__gui__.get_variable('titulo').set(__TITULO__)
        self.__gui__.get_variable('fecha').set(__FECHA__.strftime('%d/%m/%Y'))
        self.__gui__.get_variable('autor').set(__AUTOR__)
        self.__gui__.get_variable('contacto').set(__CONTACTO__)

    def licencia(self):
        archivo = os.path.abspath(os.path.join(os.path.dirname(__file__),'Licencia.html'))
        subprocess.Popen([archivo])

    def manual(self):
        proc = os.path.join(carpeta_madre, 'manual.pdf')
        if sys.platform.startswith('linux'):
            subprocess.Popen(['xdg-open', proc])
        if sys.platform.startswith('win'):
            os.startfile(proc)


def main():
    __registro__.info('{} {}, {}'.format(__NOMBRE__, __VERSION__, __TITULO__))
    try:
        root = Tk()
        root.geometry('{}x{}+0+0'.format(root.winfo_screenwidth(), root.winfo_screenheight()))
        SCET = programa(root)
        root.mainloop()
    except Exception:
        reg = os.path.join(carpeta_madre, 'registro.log')
        error = traceback.format_exc()
        __registro__.critical(error)
        msj = '''Ha ocurrido un error totalmente inesperado y el programa no va a poder continuar,
Por favor envie el archivo
{reg}
 a {autor} en {correo}
        '''.format(reg=reg, autor=__AUTOR__, correo=__CONTACTO__)
        messagebox.showerror(title='Error Critico Encontrado', icon="error", message=msj)


if __name__ == '__main__':
    main()
